@@ -4,7 +4,7 @@
   regint.h -  Oniguruma (regular expression library)
 **********************************************************************/
 /*-
- * Copyright (c) 2002-2021  K.Kosako
+ * Copyright (c) 2002-2023  K.Kosako
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -63,6 +63,7 @@
 #define USE_CALL
 #define USE_CALLOUT
 #define USE_BACKREF_WITH_LEVEL        /* \k<name+n>, \k<name-n> */
+#define USE_WHOLE_OPTIONS
 #define USE_RIGID_CHECK_CAPTURES_IN_EMPTY_REPEAT        /* /(?:()|())*\2/ */
 #define USE_NEWLINE_AT_END_OF_STRING_HAS_EMPTY_LINE     /* /\n$/ =~ "\n" */
 #define USE_WARNING_REDUNDANT_NESTED_REPEAT_OPERATOR
@@ -407,6 +408,7 @@ typedef unsigned int  MemStatusType;
 #define OPTON_NOT_BEGIN_STRING(option)    ((option) & ONIG_OPTION_NOT_BEGIN_STRING)
 #define OPTON_NOT_END_STRING(option)      ((option) & ONIG_OPTION_NOT_END_STRING)
 #define OPTON_NOT_BEGIN_POSITION(option)  ((option) & ONIG_OPTION_NOT_BEGIN_POSITION)
+#define OPTON_MATCH_WHOLE_STRING(option)  ((option) & ONIG_OPTION_MATCH_WHOLE_STRING)
 
 
 #define INFINITE_REPEAT         -1
@@ -468,8 +470,8 @@ typedef Bits*     BitSetRef;
 /* operation code */
 enum OpCode {
   OP_FINISH = 0,  /* matching process terminator (no more alternative) */
-  OP_END    = 1,  /* pattern code terminator (success end) */
-  OP_STR_1 = 2,   /* single byte, N = 1 */
+  OP_END,         /* pattern code terminator (success end) */
+  OP_STR_1,       /* single byte, N = 1 */
   OP_STR_2,       /* single byte, N = 2 */
   OP_STR_3,       /* single byte, N = 3 */
   OP_STR_4,       /* single byte, N = 4 */
